pub trait Language:
Hash
+ Eq
+ Copy
+ Clone
+ Debug
+ Display
+ Send
+ Sync
+ Serialize
+ DeserializeOwned
+ 'static {
const FILE_EXTENSIONS: &'static [&'static str];
}Expand description
Keeps a set of languages recognized by the compiler.
Required Associated Constants
Sourceconst FILE_EXTENSIONS: &'static [&'static str]
const FILE_EXTENSIONS: &'static [&'static str]
Extensions of source files recognized by the language set.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".