Module flatten

Module flatten 

Structs

Flattener
Context for flattening. Stores all sources and ASTs that are in scope of the flattening target.
FlatteningResult

Enums

FlattenerError

Functions

collect_ordered_deps
We want to make order in which sources are written to resulted flattened file deterministic.
combine_version_pragmas