pub trait Preprocessor<C: Compiler>: Debug {
// Required method
fn preprocess(
&self,
compiler: &C,
input: &mut C::Input,
paths: &ProjectPathsConfig<C::Language>,
mocks: &mut HashSet<PathBuf>,
) -> Result<()>;
}Expand description
Invoked before the actual compiler invocation and can override the input.
Updates the list of identified cached mocks (if any) to be stored in cache and updates the compiler input.
Required Methods
fn preprocess( &self, compiler: &C, input: &mut C::Input, paths: &ProjectPathsConfig<C::Language>, mocks: &mut HashSet<PathBuf>, ) -> Result<()>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".