FileFilter

Trait FileFilter 

pub trait FileFilter:
    DynClone
    + Send
    + Sync {
    // Required method
    fn is_match(&self, file: &Path) -> bool;
}
A predicate property that determines whether a file satisfies a certain condition

Required Methods

fn is_match(&self, file: &Path) -> bool

The predicate function that should return if the given file should be included.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors